breed [ residents resident ]

globals [
  mid
  low
  high

  demo-dyn
  gender-dyn

]

residents-own [
  ;; PARALLEL SOCIETY PARAMETERS
  democracy-att  ;; attitudes towards democracy
  tolerance      ;; behavioural element that helps in defining residency homogeneity
  gender-balance ;; entails the role of women in society --- higher levels entail more role for women
  dem-mean
  dem-sd
  gb-mean
  gb-sd
  tol-mean
  tol-sd
  inc-mean
  inc-sd
  num-values

  unique-id

  ;; CRIME-RELATED
  ;att-t-crime ;; this is the attitude towards criminality of the residential unit (a family, for example)
  ;payoff-crime ;; this is the payoff from criminal activity
  ;jail-time ;; self explanatory --- it is [0, 1] in the simulation

  ;; SOCIO-ECONOMIC
  income ;; this is an average over the month period (could be expressed annually)
  family ;; whether the residential unit is a family or not --- binomial [0, 1]
  education ;; this is the average level of education in the family; levels are
            ;; 1 = mostly primary; 2 = mostly secondary and/or professional
            ;; 3 = university; 4 = master; 5 or higher = PhD and above
  employment ;; this is another binomial [0, 1] or [unempl, empl]
  gov-support ;; this is related to income and family and it is whether the person is in a-kasse or
              ;; gets any other of social support from the government

  stable ;; a resident that is not up for moving from a property [0,1]
  counter ;; counts the times one has been around looking for a place and has not found it
          ;; it is used in the Schelling-new procedure to ease settling

  savings
  spread
  margin

  ;num-around
  ;similar-me
  ;other-me
]

patches-own [
  ;; THE FOLLOWING THREE HAVE BEEN ALTERED
  ;own?   ;; whether the property is owned or for rent --- another binomial [0,1]
  ;rent   ;; if the above is 0 then there is a monthly price for rent
  price   ;; there could be 5 price levels, from 1 (social housing) to 5 (luxury)
          ;; these are distributed homogeneously as areas in the map
  social?;; this is to say whether the property is social housing or not --- [0,1]
  free   ;; land that shall not be occupied by residents [0,1]
  property ;; 1 if the patch has a color such that it can be inhabited by residents [0,2]
           ;; 0 is for non residential properties, 1 for available residential property
           ;; and 2 is for unavailable residential property
  low-values  ;; calculates whether values of residents on and around the patch are low
]


to setup
  clear-all
  clear-drawing
  clear-patches

  ;; modified for the sensitivity analysis
  ask n-of 100 patches [
  ;ask n-of (residential-area * 1681) patches [
    set pcolor 7
    ask patches in-radius residential-area [ set pcolor 7 ]
    ]

end

to setup-residents
  reset-ticks
  clear-turtles

  crt num_residents [
    set breed residents
    set color red
    set size 0.8
    set shape "circle"
    setxy random-pxcor random-pycor

    set income random-normal income-mean income-stdev;;3 2 ;; numbers intended in 100,000 kronen
    ;; the variable income could be made to be distributed differently, in an
    ;; attempt to mimin a more unequal distribution

    ;; NEW DOWN HERE
    set education random-poisson 2 ;; should give a good distribution
    ;; END NEW CODE

    set family random-poisson 2     ;; the distribution should allow for a variety of units within one residency
    ask residents [ if family = 0 [ ;; this is to avoid zeroes
      set family 1 ] ]

    set employment 1

    set democracy-att random-normal 1 0.5 ;; the mean for this could be made of a slider

    ifelse hetero-tolerance [
      set tolerance random-float similar-wanted
      if democracy-att >= 1.5 [ ask residents [
        set tolerance random-normal 0.85 0.05 ]
     if democracy-att <= 0.1 [ ask residents [
          set tolerance random-float 0.251 ] ]
      ] ] [
      set tolerance similar-wanted ]

    set gender-balance random-normal 0.5 0.25
    ask residents [
      if gender-balance <= 0 [ set gender-balance 0 ] ]
    ask residents [
      if gender-balance >= 1 [ set gender-balance 1 ] ]

  ]

  ;; NEW CODE HERE
  ;; NOT IMPLEMENTED IN THE HPC MODE
  if count patches with [pcolor = 7] < num_residents [
    user-message (word "There are not enough residential patches in the system. "
      "Use the 'residential-area' slider to increase "
      "them or decrease the number of residents.") ;count turtles " turtles.")
  ]

  locate-appropriately
end

to locate-appropriately
  ask patches with [pcolor <= 8 and pcolor >= 7] [
    set property 1 ]

  ask turtles with [ gov-support = 0 ] [
    if [property] of patch-here = 0 [
      setxy random-pxcor random-pycor ]
;    if [free] of patch-here = 1 [        ;; free not assigned above
;      setxy random-pxcor random-pycor ]
  ]

  let off-placed count turtles with [[pcolor] of patch-here > 8 or [pcolor] of patch-here < 7]
  ifelse off-placed = 0 [ stop ] [ locate-appropriately ]


end

to reside
  let mean-income (mean [income] of residents)
  let sd-income (standard-deviation [income] of residents)

  ask residents with [ income > ( mean-income + sd-income ) ] [
    set color 95 ]
  ask residents with [ income <= ( mean-income + sd-income ) and  income >= ( mean-income - sd-income ) ] [
    set color 46 ]

  ask n-of (round(count residents * unemployment / 100)) residents [
    set employment 0
    set income random-normal (mean [income] of residents with [color = red])
    (standard-deviation [income] of residents with [color = red])
    set color red ]

  find-a-place

end

to find-a-place  ;;NEW CODE DOWN HERE
  ask residents with [stable != 1] [
    if count turtles-here > 1 or shape = "circle" [
      if any? patches in-radius search-area with [property = 1] [
        move-to one-of patches in-radius search-area with [property = 1]
      ]
      ;locate-appropriately ]
  ] ]

end


;; NEW CODE BELOW HERE
to zones
  if residential-zones [
    ask patches with [property = 1] [
      set price 5 ]
    ask [patches with [price = 5] in-radius 20] of patch 0 0 [
      set price 4 ]
    ask [patches with [price = 4] in-radius 15] of patch 0 0 [
      set price 3 ]
    ask [patches with [price = 3] in-radius 10] of patch 0 0 [
      set price 2 ]
    ask [patches with [price = 2] in-radius 5] of patch 0 0 [
      set price 1 ]
    ]
end

to zone-colors
  if residential-zones [
    ask patches with [pcolor = 7] [
      set pcolor red ]
    ask [patches with [pcolor = red] in-radius 20] of patch 0 0 [
      set pcolor 25 ]
    ask [patches with [pcolor = 25] in-radius 15] of patch 0 0 [
      set pcolor 35 ]
    ask [patches with [pcolor = 35] in-radius 10] of patch 0 0 [
      set pcolor 125 ]
    ask [patches with [pcolor = 125] in-radius 5] of patch 0 0 [
      set pcolor 65 ]
    ]
end
;; END OF NEW CODE

;; CODE DOWN HERE NOT IMPLEMENTED
to ghetto
    ask [patches with [pcolor = 7] in-radius 3] of patch 0 0 [
      set pcolor 116
      set social? 1
      set property 1 ]

  let indigents round((1752 / 90000) * count residents)

  ask n-of indigents (residents with [ color = red ]) [
    ;; FOLLOWING LINE NEW CODE; ALSO THE OBVIOUS MODIFICATION IN THE LINE BELOW
    if any? patches with [pcolor = 116] in-radius search-area [
      move-to one-of patches in-radius search-area with [ social? = 1 ] ]
    set gov-support 1 ;; this needs to be updated with the data from the government's official document
    set shape "square"
    set stable 1
  ]
end
;; END OF CODE NOT IMPLEMENTED

;; NEW CODE HERE
to schelling

  ifelse residential-zones [
    zones
    schelling-new
    ] [
    schelling-classic
    ]


  ifelse value-adaptation [
    if count residents with [ stable = 1 ] >= 0.50 * count residents [
      adapt ]
    ] [
    if count residents with [ stable = 1 ] >= 0.90 * count residents [
      stop ]
    ]

    if any? residents [
    set mid (count turtles with [color = 46 and stable = 1] / count turtles with [color = 46])
    set low (count turtles with [color = red and stable = 1] / count turtles with [color = red])
    set high (count turtles with [color = 95 and stable = 1] / count turtles with [color = 95])
  ]

    if enter-exit [
      ask residents with [counter > relocate and shape = "circle"] [
        move-to one-of patches with [pcolor != black and property = 1] ]

      ask residents with [counter > tired-of-looking and shape = "circle"] [
        die ]
      if num_residents > count residents [
        ask n-of (random count residents) residents [
          hatch 1 [
            set shape "circle"
            set stable 0
            set counter 0 ]
          ]
    ] ]


    ifelse hetero-tolerance [
      ask residents with [stable = 1 and democracy-att < 0.5 and gender-balance < 0.25 and tolerance > 0.7] [
        ask patch-here [
          set low-values 1 ]
    ] ] [
      ask residents with [stable = 1 and democracy-att < 0.5 and gender-balance < 0.25] [
        ask patch-here [
          set low-values 1 ]
      ] ]

    ask (turtles-on patches with [low-values > 0]) with [stable = 1] [
      set label who
      ask residents with [stable = 1] in-radius area-assessment [
        set label (one-of [who] of (turtles-on patches with [low-values > 0]) with [stable = 1] in-radius area-assessment)
    ] ]
    ask residents with [label != ""] [
      ask residents with [who = label] [
        let num who
        set num-values count residents with [label = num] in-radius area-assessment
        ifelse num-values > 1 [
          set dem-mean (mean [democracy-att] of residents with [label = num] in-radius area-assessment)
          set dem-sd (standard-deviation [democracy-att] of residents with [label = num] in-radius area-assessment)
;                    foreach sort-on [who] (residents with [label = who]) [ask ? [dem-sd]]
          set gb-mean (mean [gender-balance] of residents with [label = num] in-radius area-assessment)
          set gb-sd (standard-deviation [gender-balance] of residents with [label = num] in-radius area-assessment)
          set tol-mean (mean [tolerance] of residents with [label = num] in-radius area-assessment)
          set tol-sd (standard-deviation [tolerance] of residents with [label = num] in-radius area-assessment)
          set inc-mean (mean [income] of residents with [label = num] in-radius area-assessment)
          set inc-sd (standard-deviation [income] of residents with [label = num] in-radius area-assessment)
        ] [
        set dem-mean democracy-att
        set gb-mean gender-balance
        set tol-mean tolerance
        set inc-mean income
        ]
      ] ]

    ask residents with [label = who] [
      let tot-who (count residents with [label = who])

      if tot-who = 1 [ set unique-id "area1"]
      if tot-who = 2 [
        (foreach sort (residents with [label = who]) [1 2]
          [ [?1 ?2] -> ask ?1 [ set unique-id (word "area" ?2) ] ]) ]
      if tot-who = 3 [
        (foreach sort (residents with [label = who]) [1 2 3]
          [ [?1 ?2] -> ask ?1 [ set unique-id (word "area" ?2) ] ]) ]
      if tot-who = 4 [
        (foreach sort (residents with [label = who]) [1 2 3 4]
          [ [?1 ?2] -> ask ?1 [ set unique-id (word "area" ?2) ] ]) ]
      if tot-who = 5 [
        (foreach sort (residents with [label = who]) [1 2 3 4 5]
          [ [?1 ?2] -> ask ?1 [ set unique-id (word "area" ?2) ] ]) ]
      if tot-who = 6 [
        (foreach sort (residents with [label = who]) [1 2 3 4 5 6]
          [ [?1 ?2] -> ask ?1 [ set unique-id (word "area" ?2) ] ]) ]
      if tot-who = 7 [
        (foreach sort (residents with [label = who]) [1 2 3 4 5 6 7]
          [ [?1 ?2] -> ask ?1 [ set unique-id (word "area" ?2) ] ]) ]
      if tot-who = 8 [
        (foreach sort (residents with [label = who]) [1 2 3 4 5 6 7 8]
          [ [?1 ?2] -> ask ?1 [ set unique-id (word "area" ?2) ] ]) ]
      if tot-who = 9 [
        (foreach sort (residents with [label = who]) [1 2 3 4 5 6 7 8 9]
          [ [?1 ?2] -> ask ?1 [ set unique-id (word "area" ?2) ] ]) ]
      if tot-who = 10 [
        (foreach sort (residents with [label = who]) [1 2 3 4 5 6 7 8 9 10]
          [ [?1 ?2] -> ask ?1 [ set unique-id (word "area" ?2) ] ]) ]

    ]

end

to schelling-new
  tick

  if social-housing [
    if ticks = threshold-counter [
      ask [patches with [price < 3 and property = 1] in-radius social-housing-area] of one-of (patches with [price < 3 and property = 1]) [
        set social? 1
        set pcolor blue ]
  ] ]

  ask residents with [stable != 1] [
    let num-around (count other residents in-radius area-assessment)
    let similar-me (count other residents with [color = [color] of myself] in-radius area-assessment)
    let other-me num-around - similar-me

    set savings (education / 5) * (0.20 * income) ;; assume that 20% is the max one wants to spare on housing money
    set spread (income - [price] of patch-here) ;; difference between money available and price
    set margin (spread - savings) ;; whether the difference falls within the range of savings
    ;; if it is > 0 it means that the residence is too cheap and another must be found
    ;; if it is < 0 then the residence is affordable

    ;let indigents count residents with [color = red and shape = "circle"] ;; NOT APPLIED

    ;; code below to increase the chances of residents to find a place in the map
    if counter > threshold-counter [
      set margin 0
;      if (count residents with [color = red] - indigents) / count residents with [color = red] < 0.10 [
;        ask n-of (indigents / 2) (patches with [price < 3 and property = 1]) [
;          set social? 1
;          set pcolor blue ]
        ask residents with [color = red and stable != 1] [
          if [social?] of patch-here = 1 [
            set shape "square"
            set stable 1
            ask patch-here [ set property 2 ] ;; there is something wrong with this, when the 'tired-of-looking' kicks in //
            set counter 0                     ;; some patches show property = 2 when no resident is in...
          ] ]
    ]

    ifelse spread > 0 and margin <= 0 [
  ;; THIS below here is schelling-classic:
    ifelse similar-me < round (tolerance * num-around) [
      ifelse any? patches in-radius search-area with [property = 1 and count turtles-here = 0] [
        move-to one-of (patches in-radius search-area with [property = 1 and count turtles-here = 0])
          set counter counter + 1
      ] [
      find-a-place
      set counter counter + 1
        ]
      ] [
      ifelse [social?] of patch-here != 1 and count turtles-on patch-here = 1 [
        set shape "square"
        set stable 1
        ask patch-here [ set property 2 ]
        set counter 0
        ] [
        if any? patches in-radius search-area with [property = 1 and count turtles-here = 0] [
          move-to one-of (patches in-radius search-area with [property = 1 and count turtles-here = 0]) ]
        set counter counter + 1
    ] ]
  ;; END of schelling-classic
      ] [
      if count turtles-here > 1 or shape = "circle" [
        if any? patches in-radius search-area with [property = 1 and count turtles-here = 0] [
          move-to one-of patches in-radius search-area with [property = 1 and count turtles-here = 0]
          set counter counter + 1
      ] ]
      ]
  ]

end

to schelling-classic
;; END NEW CODE HERE
  tick

  ask residents with [stable != 1] [ ;; NOTICE THE CHANGE
  ;ask residents with [([social?] of patch-here != 1) or stable != 1] [

  ;; NOW 'LET' INSTEAD OF 'SET' --- SEE THE CHANGE ABOVE
    let num-around (count other residents in-radius area-assessment)
    let similar-me (count other residents with [color = [color] of myself] in-radius area-assessment)
    let other-me num-around - similar-me

    ifelse similar-me < round (tolerance * num-around) [
      ifelse any? patches in-radius search-area with [property = 1 and count turtles-here = 0] [
        move-to one-of (patches in-radius search-area with [property = 1 and count turtles-here = 0])
        set counter counter + 1
      ] [
        find-a-place
        set counter counter + 1
        ]
      ] [
      ifelse count turtles-on patch-here = 1 [
        set shape "square"
        set stable 1
        ask patch-here [ set property 2 ] ;; the property is occupied by someone
        set counter 0
    ] [
    if any? patches in-radius search-area with [property = 1 and count turtles-here = 0] [
      move-to one-of (patches in-radius search-area with [property = 1 and count turtles-here = 0]) ]
    set counter counter + 1
    ]
  ] ]

end


to adapt
  set demo-dyn mean ([democracy-att] of residents with [shape = "square" and democracy-att < 0.5])
  set gender-dyn (mean [gender-balance] of residents with [shape = "square" and gender-balance < 0.30])

  ask residents with [shape = "square"] [
    if count residents with [shape = "square"] in-radius area-assessment > 2 [

    let mean-demo (mean [democracy-att] of residents with [shape = "square"] in-radius area-assessment)
    ;let mean-tolerance (mean [tolerance] of residents with [shape = "square"] in-radius area-assessment)
    let mean-gender (mean [gender-balance] of residents with [shape = "square"] in-radius area-assessment)

    let sd-demo (standard-deviation [democracy-att] of residents with [shape = "square"] in-radius area-assessment)
    ;let sd-tolerance (standard-deviation [tolerance] of residents with [shape = "square"] in-radius area-assessment)
    let sd-gender (standard-deviation [gender-balance] of residents with [shape = "square"] in-radius area-assessment)

    if mean-demo <= (mean [democracy-att] of residents - sd-demo) [
      if democracy-att < (mean [democracy-att] of residents - sd-demo / 2) [
        set democracy-att (democracy-att - democracy-update)
      ] ]

    if mean-gender <= (mean [gender-balance] of residents - sd-gender) [
      if gender-balance < (mean [gender-balance] of residents - sd-gender / 2) [
        set gender-balance (gender-balance - gender-update)
        if gender-balance < 0 [ set gender-balance 0 ]
      ] ]
      ;; shocks can be put in the system; maybe elections? If a tick is a 'week' then, with 52 weeks on a year
      ;; there are 208 ticks between elections: ticks / (100 + 208)

      if elections-RW [
        if ticks / 208 = 1 or ticks / 208 = 2 or ticks / 208 = 3 [
          if mean-demo <= (mean [democracy-att] of residents - sd-demo) [
            if democracy-att < (mean [democracy-att] of residents - sd-demo) [
              set democracy-att (democracy-att - democracy-update * 2)
      ] ]
          if mean-gender <= (mean [gender-balance] of residents - sd-gender) [
            if gender-balance < (mean [gender-balance] of residents - sd-gender) [
              set gender-balance (gender-balance - gender-update * 2)
      ] ]
        ] ]

  ] ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copyright Davide Secchi 2018
;; Research Centre for Computational & Organisational Cognition
;; University of Southern Denmark, Slagelse
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@#$#@#$#@
GRAPHICS-WINDOW
218
10
809
602
-1
-1
14.22
1
10
1
1
1
0
1
1
1
-20
20
-20
20
0
0
1
ticks
30.0

BUTTON
21
93
108
126
setup-all
setup\nsetup-residents\nreside
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
21
24
197
57
num_residents
num_residents
0
1000
800.0
50
1
NIL
HORIZONTAL

SWITCH
20
291
197
324
hetero-tolerance
hetero-tolerance
0
1
-1000

SLIDER
19
502
198
535
unemployment
unemployment
0
20
4.3
0.1
1
NIL
HORIZONTAL

SLIDER
20
192
197
225
similar-wanted
similar-wanted
0
1
0.3
0.01
1
NIL
HORIZONTAL

SLIDER
20
225
197
258
search-area
search-area
0
15
3.0
0.1
1
NIL
HORIZONTAL

BUTTON
110
129
197
162
NIL
schelling
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
110
93
197
126
NIL
schelling
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
21
57
197
90
residential-area
residential-area
0
5
2.0
1
1
NIL
HORIZONTAL

MONITOR
989
405
1048
450
settlers
count residents with [shape = \"square\"] / count residents
2
1
11

SLIDER
20
258
197
291
area-assessment
area-assessment
0
15
3.0
0.1
1
NIL
HORIZONTAL

SWITCH
20
375
197
408
residential-zones
residential-zones
1
1
-1000

BUTTON
23
645
138
678
see-zone-color
zone-colors
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
23
680
138
713
grey-colored
ask patches with [pcolor != black] [set pcolor 7]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
20
408
197
441
income-mean
income-mean
0
5
2.5
0.1
1
NIL
HORIZONTAL

SLIDER
20
441
197
474
income-stdev
income-stdev
0
5
1.0
0.1
1
NIL
HORIZONTAL

MONITOR
830
405
893
450
margin
mean [margin] of residents
2
1
11

MONITOR
1048
405
1163
450
possible-settlers
count residents with [margin <= 0 and spread > 0]
2
1
11

PLOT
830
14
1163
204
Settlers et al
Time
Number of residents
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"susceptibles" 1.0 0 -14835848 true "" "plot count residents with [margin <= 0 and spread > 0]"
"settlers" 1.0 0 -2674135 true "" "plot count residents with [stable = 1]"

PLOT
830
204
1163
404
Settling per income type
Time
Proportion of residents
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"mid" 1.0 0 -987046 true "" "plot mid"
"low" 1.0 0 -2674135 true "" "plot low"
"high" 1.0 0 -13791810 true "" "plot high"

INPUTBOX
170
647
278
713
threshold-counter
10.0
1
0
Number

SWITCH
278
647
437
680
social-housing
social-housing
1
1
-1000

SLIDER
278
680
437
713
social-housing-area
social-housing-area
0
5
3.0
0.1
1
NIL
HORIZONTAL

SWITCH
464
647
583
680
enter-exit
enter-exit
1
1
-1000

INPUTBOX
464
680
583
740
tired-of-looking
30.0
1
0
Number

INPUTBOX
583
647
702
707
relocate
20.0
1
0
Number

MONITOR
892
405
989
450
#residents
count residents
0
1
11

TEXTBOX
173
629
387
647
Commands for social housing
11
43.0
1

TEXTBOX
23
9
173
27
Setup and go procedures
11
43.0
1

TEXTBOX
21
174
215
202
Assuptions for residential settling
11
43.0
1

TEXTBOX
21
489
171
507
Not yet implemented
11
63.0
1

TEXTBOX
21
356
212
374
Introduction of house prices
11
43.0
1

TEXTBOX
22
615
154
643
Visualise the residential house prices
11
103.0
1

TEXTBOX
467
624
677
642
Entering and exiting the map
11
43.0
1

SWITCH
834
661
996
694
value-adaptation
value-adaptation
1
1
-1000

SLIDER
834
694
996
727
democracy-update
democracy-update
0
0.01
0.001
0.001
1
NIL
HORIZONTAL

SLIDER
996
693
1158
726
gender-update
gender-update
0
0.01
0.001
0.001
1
NIL
HORIZONTAL

SWITCH
996
661
1158
694
elections-RW
elections-RW
1
1
-1000

TEXTBOX
836
643
986
661
Radicalising?
11
43.0
1

PLOT
829
450
1164
637
Value dynamics (lower ≈25% percentiles)
Time
Values
0.0
10.0
0.0
0.4
true
true
"" ""
PENS
"democracy" 1.0 1 -16777216 true "" "plot demo-dyn"
"gender" 1.0 1 -14070903 true "" "plot gender-dyn"

@#$#@#$#@
## WHAT IS IT?

The starting point is information published in March 2018 by the Danish government <i>Et Danmark uden parallelsamfund</i> (One Denmark without parallel society). The plan is to eliminate what they call 'parallel society' in the country (see below) by getting rid of areas officially called ghettoes by 2030. These areas are neighborhoods where the local municipalities allow poor citizens to reside, paying a rent they can afford (social housing). 

Information on how to operationalise the plan is meagre. However, before being concerned with the plan of how to erase ghettoes from the map of Danish cities, one should ask the question on whether a parallel society is something that could form, given the current socio-economic picture.

The problem should be tackled by a three-step approach: (A) estimating the possibility of a 'parallel society' formation, (B) defining whether it is located in a so-called ghetto area, and (C) exploring the implications of erasing a ghetto area from the map. All these steps are tested on areas where the government indicates there are the official ghetto areas. However, such a map and the number of residents necessary to have a more realistic picture require intense computational power. Hence, before running the model full scale, we have created the current model as a test bed for dynamics to be applied later to the larger scale model. 

The model currently presented here is a 1/100 scale of an area in the city of Copenhagen, and it represents possible configurations of neighborhoods. We have artificially created several conditions to observe whether some of the elements we want to test on the full model have an impact in this smaller scale model. And, of course, we want to analyse what this impact would be. 

This version of the model only covers the first step (A) on <b>society formation</b>, as described above.

## HOW IT WORKS

This is a very interesting and long standing topic in sociology (see Martin Neumann's work). The concept of a 'parallel' society implies a way of organising that is different (perhaps incompatible?) from the established ways of an already established society. Hence, it leans on (a) radically different values, (b) different social norms, (c) non-standard behaviour (standard being the one from the majority of society), and generating (d) conflict with the other 'parallel' social majority.

The first step would be to see which one between (a), (b), and (c) lead to the formation of a 'parallel' society. Clearly, a society (any society) is autonomous but not completely independent from other societies. But it is different enough, so that it can be thought of being 'separate' or 'parallel' to the other. The general idea is that those living in the ghetto constitute a 'parallel' society. Let us take the following assumptions forward in the simulation:

### <a style="color:white;">Values</a>
We start from attributing values to agents in the entire society. We assume that some agents have values that are distant from those of the mean. These values are mostly grounded in (to stick to the Danish government's predicament) the acceptance of a <b>democracy</b>, </b>tolerance</b>, and <b>role of women</b>.

#### Democracy
The range for democracy acceptance is such that a random-normal distribution with mean = 1 and standard deviation = 0.5 will determine those that believe in its worth (around the average and up) and those that are less positive about it, to include/consider those that are negative. The latter group include extremists of various kinds, both political extremists and actual or potential religious fundamentalists.

#### Tolerance
This is a bit more tricky to consider. Tolerance is a value that has clear behavioural implications, at least, for simulated residents in our simulation. This is linked to the model by Schelling on segregation. In his model, ultimately agents had a general feeling of happiness directly linked to the extend to which their neighbours were similar to themseleves. That was homogeneous in the entire society. In this simulation, tolerance has to be considered heterogeneous, so that it could vary at the individual level. Tolerance is very much related to the neighbourhood one lives in. If it is high, then there is not much of an issue in defining which neighbours one has. If it is on the low, then most surrounding agents must be similar to the self. The value is set on a range that goes between 0 and 1. The only condition in the setting is that individuals with very high democratic values will also approach high tolerance. On the contrary, those with negative democratic values will be mostly intolerant. Everyone else will have random values for tolerance.

When the switch 'hetero-tolerance' is OFF, the model works very similarly to the segregation model in the NetLogo version (also available among the NetLogo Library Models). When it is turned to ON, this switch allows for the population of agents to have a max tolerance for diversity set by the proportion in the 'similar-wanted' slider. 

#### Gender balance
The simulation works around resident units. This means that each agent is a resident and this could be a single individual, or a family. The family could be formed by just two individuals, or more. 2 and 3 residential units are the most diffused in the system. Now, independent of the number of individuals in the residence unit, there is an assumption on gender balance; whether it is high/low on a scale that sees it ranging from 0 to 1, where 0.5 (or around it) is a balanced view and values going down to zero are progressively more unbalanced. Values close or down to 0 mean that there is complete separation of roles between men and women in society, with a strict masculine take. Values close to 1 have opposite meaning, showing a close to total feminist residence unit.

#### The agent
In this simulation, the agent is a 'residence unit', not necessarily an individual. For residence unit, we mean to refer to the family that occupies a house or apartment. Hence, all information on the agent is an average of the members of the unit, unless the unit has only one individual. The 'family' is set using a random-poisson with a mean of 2. The probability of having a residence unit with more than 5 members is less than 3%.

### <a style="color:white;">The starting point: Schelling's model</a>
To study how residents settle in a neighborhood, this simulation takes the original segregation model by Schelling (1971), with a few adjustments.

#### Similarity
In this simulation, the level of similarity is determined by the level of income that is attributed to each agent via a random normal distribution. The two sliders under the section 'Introduction to house prices' allow users to determine the mean and the standard deviation for income. This is such that agents receive an average amount, and this is visible by their color in the map: <b style="color:#E6D726;">yellow</b> agents are the middle class, <b style="color:red;">red</b> agents have low income, and the <b style="color:#25B4EE;">blue</b> ones have high income.

The income is used mostly when the 'residential-zones' switch is turned ON. Also, notice that the income considered here is only the portion of a residential unit's money that is dedicated to housing (i.e. it is not their total income).

The slider 'similar-wanted' gives the proportion of agents of similar income range (yellow, red, or blue) that each agent would like to have around it before settling. If the proportion of agents, calculated around the 'area-assessment' range, is more than the one indicated in the slider, then the agent moves around to another patch on the map that is consistent with the range expressed in the 'search-area'. 

<a style="color:#57A524;">[Notice that this slider is just one in the NetLogo version of Schelling's model. We wanted to make it such that the assessment on neighbors could be performed on a wider or (more typically) smaller scale than the area in which one searches for a residence.]</a>

#### Residential zones
When the switch 'residential-zones' is ON, then the map is divided into 5 different residential areas (visible by clicking on the 'see-zone-color' button). These areas are more affordable (cheap) around the middle of the area and less so as one moves to the periphery. The levels of income---as set by the two sliders---determine how easy it will be for agents to find an appropriate residence.

This element works as an additional constraint on the tolerance-based setting. Even though that remains the ultimate assessment that agents make before settling, the definition of residential areas impose a stricter range of options because low income (red) agents cannot afford those residential areas in the periphery and high income agents do not want to settle in the centre of the map.

The mechanism has two stages. In the <b>first</b>, each agent compares the income to the price of the residential place (the patch). If this difference is positive, then it considers how much it can afford to save. Savings on residential money are indexed on education, such that more educated individuals are those who save more, and up to a maximum of 20% of their income.
The second step is defined by the 'commands for social housing' (bottom left of the panel interface). If 'social-housing' is turned ON, then a blue area appears on a random spot in the map. This is set in between the two areas where residential areas have the lowest prices and it extends depending on the value indicated in the slider 'social-housing-area'. The area for social housing (or 'ghetto' as per the Danish system) appears when ticks equal the number inputed in the input box 'threshold-counter'.

#### Entering and exiting the area
Some residents may become 'tired-of-looking' for a place to settle, after a while (the value indicated in the input box). The value indicates the number of ticks an agent has been looking for a resindence without finding any. If, after that many rounds, one is still looking, then it exists the system (meaning that it moves the search elsewhere, and not in this particular residential area we are interested in). Before hitting that number, one may suggest that agents change the area they are looking to settle in. The input box 'relocate' allows users to do that, and agents that have not yet settled choose another place at random where to look for a residence.

It goes without saying that all of this only works if the switch 'enter-exit' is set to ON.

#### Value adaptation
The assumption of the model is that values adapt very slowly. The commands at the bottom right part of the interface allow one to manipulate the extent to which values (mostly democracy and gender balance) change, based on the surroundings. When the switch 'value-adaptation' is ON, then those settled residents scoring an already low level in both of these values, and living in an area where the mean values of these two values is significantly low (calculated in sd distance from the population mean), then the adaptation adjusts depending on the two sliders 'democracy-update' and 'gender-update'.

A general election with a shocking result would either move towards the area in which the party won (e.g., right-wing in this model; see 'elections-RW') those that are closer to that area in the democracy spectrum. At the same time, those in the opposite side of the spectrum will radicalise, with the impression to become better equipped to fight the extremism of the government. (Only the first part of the argument---i.e. radicalisation---implemented so far.)

## HOW TO USE IT

Before starting the model, users should indicate the number of residents in the area, together with the size of the areas that are residential areas on the map. The first number is set by the slider 'num_residents' while the second is defined by the other slider named 'residential-area'. When there is incompatibility between these values, a message will pop up and advise on what to do.

The setup button has functions that are standard for NetLogo models, while the button 'schelling' (continuous and not) has the function of the 'go' button in other models. Depending on the setting described above, the simulation performs a classic Schelling segregation model or an adapted (new) version of it.

## THINGS TO NOTICE AND TO TRY

Many features of this model remain similar to those from Schelling's. It is worth noting that small variations, for example, in the use of tolerance (similar-wanted) or of the two areas (search and assessment) show results that are very different from the original model by Schelling. 

In addition to these results, one could also attempt at moving up the population mean income and reduce its standard deviation, when residential areas are set to ON. This should increase the likelihood for most people to find a residence. Vice-versa, a lower mean income lets the poor (red agents) wonder around without the possibility of settling. When social housing (a ghetto) becomes available, they tend to cram onto that spot in the map. 
Also, given that they are the ones to disappear from the map if 'enter-exit' is ON, when income is low on average, the area becomes a 'posh' or exclusive neighborhood.


## EXTENDING THE MODEL

As mentioned above, there are additional steps to extend this model. This is, on the one hand, the first of three models. Hence, obvious extensions relate to the disappearance of the ghetto area (called social housing in the commands) and to the adaptation that agents may have while interacting as neighbors. This second aspect is, perhaps, the most interesting because it allows to study how agents adapt their thinking/behavior (especially on those three values we have identified above---democracy, tolerance, and gender balance) depending on the area of residence. Adaptation will then make is possible to fully explore the possibility that a parallel society may form, not straight away, but as agents (residents) live in a place. <b style="color:#25B4EE;">Now implemented! Still checks and improvements needed.</b>

On the other hand, this model constitutes the groundwork for making a study on the areas of Denmark where 'ghettoes' are located. In other words, the extension would be to produce a larger scale model (about 100 times larger) and on the actual territories where the government is currently planning on intervening. Such a new simulation would require a computer with vast computational power.


## NETLOGO FEATURES

As social scientists, most features of the software are good enough. However, the area where much work has been dedicated is the one where residential areas have different prices. Nothing too complicated has been created there, but the way the agents relate their income to the area and then apply a version of the 'segregation' model is probably noteworthy. Also, given the modifications to the original mechanisms in Schelling's model, the code features several 'ifelse' loops that may take a while to be fully disentangled and understood. They achieve the intended goal.


## RELATED MODELS

We have been referring to Schelling's model, in the version in which it is available in the NetLogo Models Library, called 'segregation'. There are many modifications and uses of this model, but its reference has probably been the most inspiring for this work.


## CREDITS AND REFERENCES

The model is part of a paper (currently under review for the 'Journal of Simulation') and it is available on the online repository OpenABM. Full references and url will be available when the related paper is accepted.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="sensitivity1.0_basics" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity2.0_res_zones" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity1.1_soc_housing" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="2"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity2.1.0_soc_housing" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="2"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity1.2_enter" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="30"/>
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity2.0.1_enter" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="30"/>
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity1.1.1_enter" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="2"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="30"/>
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity2.1.0_enter" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="2"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity2.1.1_soc_housing" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="2"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity2.1.1_enter" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="2"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity2.0.0_enter" repetitions="1" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <steppedValueSet variable="num_residents" first="400" step="100" last="800"/>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <steppedValueSet variable="similar-wanted" first="0.3" step="0.1" last="0.8"/>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="3"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2"/>
      <value value="3"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="30"/>
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="fullModel_test" repetitions="2" runMetricsEveryStep="false">
    <setup>setup
setup-residents
reside</setup>
    <go>schelling</go>
    <timeLimit steps="208"/>
    <metric>low</metric>
    <metric>mid</metric>
    <metric>high</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area1"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area1"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area1"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area2"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area2"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area2"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area3"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area3"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area3"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area4"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area4"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area4"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area5"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area5"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area5"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area6"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area6"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area6"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area7"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area7"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area7"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area8"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area8"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area8"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area9"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area9"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area9"]</metric>
    <metric>sum [dem-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [dem-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [gb-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [tol-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-mean] of residents with [unique-id = "area10"]</metric>
    <metric>sum [inc-sd] of residents with [unique-id = "area10"]</metric>
    <metric>sum [num-values] of residents with [unique-id = "area10"]</metric>
    <enumeratedValueSet variable="num_residents">
      <value value="400"/>
      <value value="800"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-area">
      <value value="1"/>
      <value value="2"/>
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="similar-wanted">
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="search-area">
      <value value="1"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="area-assessment">
      <value value="1"/>
      <value value="6"/>
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="hetero-tolerance">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="residential-zones">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-mean">
      <value value="2.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="income-stdev">
      <value value="1"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="threshold-counter">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="social-housing-area">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="enter-exit">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="relocate">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="tired-of-looking">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="value-adaptation">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gender-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="democracy-update">
      <value value="0.001"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="elections-RW">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="unemployment">
      <value value="4.3"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
